**Example 1: 暂停预测式外呼任务示例**

暂停预测式外呼任务

Input: 

```
tccli ccc PausePredictiveDialingCampaign --cli-unfold-argument  \
    --SdkAppId 1400000000 \
    --CampaignId 2569
```

Output: 
```
{
    "Response": {
        "RequestId": "3c140219-cfe9-470e-b241-907877d6fb03"
    }
}
```

